@@ -28,7 +28,8 @@ template <int TYPE = PERF_TYPE_HARDWARE> class LinuxEvents {
   perf_event_attr attribs{};
   size_t num_events{};
   std::vector<uint64_t> temp_result_vec{};
-  std::vector<uint64_t> ids{};
+  std::vector<uint64_t> result{};
+  std::vector<int> fds{};
   bool quiet;
 
 public:
@@ -48,15 +49,17 @@ public:
 
     int group = -1; // no group
     num_events = config_vec.size();
-    ids.resize(config_vec.size());
+    result.resize(config_vec.size());
     uint32_t i = 0;
     for (auto config : config_vec) {
       attribs.config = config;
-      fd = static_cast<int>(syscall(__NR_perf_event_open, &attribs, pid, cpu, group, flags));
-      if (fd == -1) {
+      int _fd = static_cast<int>(syscall(__NR_perf_event_open, &attribs, pid, cpu, group, flags));
+      if (_fd == -1) {
         report_error("perf_event_open");
       }
-      ioctl(fd, PERF_EVENT_IOC_ID, &ids[i++]);
+      fd = _fd; // fd tracks the last _fd value.
+      fds.push_back(fd);
+      ioctl(fd, PERF_EVENT_IOC_ID, &result[i++]);
       if (group == -1) {
         group = fd;
       }
@@ -65,7 +68,11 @@ public:
     temp_result_vec.resize(num_events * 2 + 1);
   }
 
-  ~LinuxEvents() { if (fd != -1) { close(fd); } }
+  ~LinuxEvents() {
+   for (auto tfd : fds) {
+      if (tfd != -1) { close(tfd); }
+    }
+  }
 
   inline void start() {
     if (fd != -1) {
@@ -90,7 +97,7 @@ public:
       }
     }
     // our actual results are in slots 1,3,5, ... of this structure
-    // we really should be checking our ids obtained earlier to be safe
+    // we really should be checking our result obtained earlier to be safe
     for (uint32_t i = 1; i < temp_result_vec.size(); i += 2) {
       results[i / 2] = temp_result_vec[i];
     }
