@@ -13,7 +13,7 @@ using namespace simdjson::dom;
 
 class implementation final : public simdjson::implementation {
 public:
-  simdjson_really_inline implementation() : simdjson::implementation(
+  simdjson_inline implementation() : simdjson::implementation(
       "fallback",
       "Generic fallback implementation",
       0
@@ -30,4 +30,4 @@ public:
 } // namespace fallback
 } // namespace simdjson
 
-#endif // SIMDJSON_FALLBACK_IMPLEMENTATION_H
\ No newline at end of file
+#endif // SIMDJSON_FALLBACK_IMPLEMENTATION_H
