@@ -6,6 +6,53 @@ using namespace simdjson;
 namespace object_tests {
   using namespace std;
   using simdjson::ondemand::json_type;
+  bool issue1745() {
+    TEST_START();
+    auto json = R"({
+  "keys": [
+    {
+      "kid": "bbd2ac7c4c5eb8adc8eeffbc8f5a2dd6cf7545e4",
+      "e": "AQAB",
+      "alg": "RS256",
+      "use": "sig",
+      "n": "y930dtGTeMG52IPsKmMuEpPHLaxuYQlduZd6BqFVjc2-UFZR8fNqtnYzAjbXWJD_Tqxgdlj_MW4vogvX4sHwVpZONvdyeGoIyDQtis6iuGQhQamV85F_JbrEUnEw3QCO87Liz5UXG6BK2HRyPhDfMex1_tO0ROmySLFdCTS17D0wah71Ibpi0gI8LUi6kzVRjYDIC1oE-iK3Y9s88Bi4ZGYJxXAbnNwbwVkGOKCXja9k0jjBGRxZD-4KDuf493lFOOEGSLDA2Qp9rDqrURP12XYgvf_zJx_kSDipnr0gL6Vz2n3H4-XN4tA45zuzRkHoE7-XexPq-tv7kQ8pSjY2uQ",
+      "kty": "RSA"
+    },
+    {
+      "kty": "RSA",
+      "n": "zMHxWuxztMKXdBhv3rImlUvW_yp6nO03cVXPyA0Vyq0-M7LfOJJIF-OdNoRGdsFPHVKCFoo6qGhR8rBCmMxA4fM-Ubk5qKuUqCN9eP3yZJq8Cw9tUrt_qh7uW-qfMr0upcyeSHhC_zW1lTGs5sowDorKN_jQ1Sfh9hfBxfc8T7dQAAgEqqMcE3u-2J701jyhJz0pvurCfziiB3buY6SGREhBQwNwpnQjt_lE2U4km8FS0woPzt0ccE3zsGL2qM-LWZbOm9aXquSnqNJLt3tGVvShnev-GiJ1XfQ3EWm0f4w0TX9fTOkxstl0vo_vW_FjGQ0D1pXSjqb7n-hAdXwc9w",
+      "alg": "RS256",
+      "kid": "85828c59284a69b54b27483e487c3bd46cd2a2b3",
+      "e": "AQAB",
+      "use": "sig"
+    }
+  ]
+}
+
+  })"_padded;
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    for (auto items_instance : doc["keys"]) {
+      ondemand::object items;
+      ASSERT_SUCCESS(items_instance.get_object().get(items));
+      std::string_view kty_value;
+      ASSERT_SUCCESS(items["kty"].get_string().get(kty_value));
+      std::string_view use_value;
+      ASSERT_SUCCESS(items["use"].get_string().get(use_value));
+      if (kty_value != "RSA" && use_value != "sig") { continue; }
+      std::string_view str;
+      ASSERT_SUCCESS(items["alg"].get_string().get(str));
+      ASSERT_EQUAL(str, "RS256");
+      ASSERT_EQUAL(use_value, "sig");
+      ASSERT_EQUAL(kty_value, "RSA");
+      ASSERT_SUCCESS(items["n"].get_string().get(str));
+      ASSERT_EQUAL(str.size(), 342);
+      ASSERT_SUCCESS(items["e"].get_string().get(str));
+      ASSERT_EQUAL(str, "AQAB");
+    }
+    TEST_SUCCEED();
+  }
 
   bool issue1723() {
     TEST_START();
@@ -178,6 +225,47 @@ namespace object_tests {
   }
 
 #if SIMDJSON_EXCEPTIONS
+  bool issue1745_with_exceptions() {
+    TEST_START();
+    auto json = R"({
+  "keys": [
+    {
+      "kid": "bbd2ac7c4c5eb8adc8eeffbc8f5a2dd6cf7545e4",
+      "e": "AQAB",
+      "alg": "RS256",
+      "use": "sig",
+      "n": "y930dtGTeMG52IPsKmMuEpPHLaxuYQlduZd6BqFVjc2-UFZR8fNqtnYzAjbXWJD_Tqxgdlj_MW4vogvX4sHwVpZONvdyeGoIyDQtis6iuGQhQamV85F_JbrEUnEw3QCO87Liz5UXG6BK2HRyPhDfMex1_tO0ROmySLFdCTS17D0wah71Ibpi0gI8LUi6kzVRjYDIC1oE-iK3Y9s88Bi4ZGYJxXAbnNwbwVkGOKCXja9k0jjBGRxZD-4KDuf493lFOOEGSLDA2Qp9rDqrURP12XYgvf_zJx_kSDipnr0gL6Vz2n3H4-XN4tA45zuzRkHoE7-XexPq-tv7kQ8pSjY2uQ",
+      "kty": "RSA"
+    },
+    {
+      "kty": "RSA",
+      "n": "zMHxWuxztMKXdBhv3rImlUvW_yp6nO03cVXPyA0Vyq0-M7LfOJJIF-OdNoRGdsFPHVKCFoo6qGhR8rBCmMxA4fM-Ubk5qKuUqCN9eP3yZJq8Cw9tUrt_qh7uW-qfMr0upcyeSHhC_zW1lTGs5sowDorKN_jQ1Sfh9hfBxfc8T7dQAAgEqqMcE3u-2J701jyhJz0pvurCfziiB3buY6SGREhBQwNwpnQjt_lE2U4km8FS0woPzt0ccE3zsGL2qM-LWZbOm9aXquSnqNJLt3tGVvShnev-GiJ1XfQ3EWm0f4w0TX9fTOkxstl0vo_vW_FjGQ0D1pXSjqb7n-hAdXwc9w",
+      "alg": "RS256",
+      "kid": "85828c59284a69b54b27483e487c3bd46cd2a2b3",
+      "e": "AQAB",
+      "use": "sig"
+    }
+  ]
+}
+
+  })"_padded;
+    ondemand::parser parser;
+    ondemand::document doc = parser.iterate(json);
+    for (auto items : doc["keys"]) {
+      std::string_view kty_value = items["kty"].get_string();
+      std::string_view use_value = items["use"].get_string();
+      if (kty_value != "RSA" && use_value != "sig") { continue; }
+      std::string_view str = items["alg"].get_string();
+      if(str != "RS256") { return false; }
+      if(use_value != "sig") { return false; }
+      if(kty_value != "RSA") { return false; }
+      str = items["n"].get_string();
+      if(str.size() != 342) { return false; }
+      str = items["e"].get_string();
+      if(str != "AQAB") { return false; }
+    }
+    TEST_SUCCEED();
+  }
 
   bool issue1723_except() {
     TEST_START();
@@ -808,6 +896,49 @@ namespace object_tests {
     TEST_SUCCEED();
   }
 
+  bool issue1876a() {
+    TEST_START();
+    auto json = R"( {} )"_padded;
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    ondemand::object obj;
+    ASSERT_SUCCESS(doc.get_object().get(obj));
+    size_t count;
+    ASSERT_SUCCESS(obj.count_fields().get(count));
+    ASSERT_EQUAL(count, 0);
+    for (auto field : obj) {
+      std::string_view key;
+      ASSERT_SUCCESS(field.unescaped_key().get(key));
+      double value;
+      ASSERT_SUCCESS(field.value().get_double().get(value));
+      std::cout << key << " " << value << std::endl;
+    }
+    TEST_SUCCEED();
+  }
+
+  bool issue1876() {
+    TEST_START();
+    auto json = R"( {} )"_padded;
+    ondemand::parser parser;
+    ondemand::document doc;
+    ASSERT_SUCCESS(parser.iterate(json).get(doc));
+    size_t count;
+    ASSERT_SUCCESS(doc.count_fields().get(count));
+    ondemand::object obj;
+    ASSERT_SUCCESS(doc.get_object().get(obj));
+
+    ASSERT_EQUAL(count, 0);
+    for (auto field : obj) {
+      std::string_view key;
+      ASSERT_SUCCESS(field.unescaped_key().get(key));
+      double value;
+      ASSERT_SUCCESS(field.value().get_double().get(value));
+      std::cout << key << " " << value << std::endl;
+    }
+    TEST_SUCCEED();
+  }
+
   bool issue1742() {
     TEST_START();
     auto json = R"( {
@@ -986,8 +1117,114 @@ namespace object_tests {
     TEST_SUCCEED();
   }
 
+
+  bool test_strager() {
+    // Find exactly one of a/myint or b/myint, if both or none are present,
+    // return false.
+    auto process = [](ondemand::object root) -> std::pair<bool,uint64_t> {
+      ///////////////////////////////////////////////////////////
+      // The core idea with On-Demand is that you should visit everything only
+      // once.
+      //
+      // Thus, with On-Demand, you must consume a field once you have accessed it.
+      // Thus if you do root["a"], you must full consume the corresponding
+      // value (if present) before you move to another field (e.g., root["a"]).
+      //
+      // If, somehow, you only want the value corresponding to "a" if some
+      // other key is not present, then you must still parse/consume the value
+      // corresponding to "a", and later throw the result away.
+      ///////////////////////////////////////////////////////////
+      uint64_t myint;
+      // Notice in the line below that I use chaining... I do not
+      // first convert root["a"] to an object and then seek
+      // "myint" into. Chaining works in this instance because
+      // I only need to access the object 'root["a"]' for a single
+      // key, if I needed to do more work on root["a"], then I should
+      // create an object.
+      if(root["a"]["myint"].get(myint) == SUCCESS) {
+        // We want myint to be discarded if "b" is also present.
+        if(! root["b"].error() ) {
+          // Oops, the other key is also present!!! We must throw
+          // away 'myint' and return false.
+          // Notice how I do not parse the value corresponding to
+          // '"b"', as it is unneeded.
+          return std::make_pair(false, 0);
+        }
+        // All is good,
+        return std::make_pair(true,myint);
+      }
+      // Now we know that "a" is not present, so seek "b".
+      if(root["b"]["myint"].get(myint) == SUCCESS) {
+        return std::make_pair(true, myint);
+      }
+      // None are present.
+      return std::make_pair(false, 0);
+    };
+
+    TEST_START();
+
+    {
+      ondemand::parser parser;
+      padded_string json = R"({ "a": { "myint": 42 } })"_padded;
+      std::cout << " - Subtest 'a' - JSON: " << (json) << " ..." << std::endl;
+      ondemand::document doc;
+      ASSERT_SUCCESS(parser.iterate(json).get(doc));
+      ondemand::object obj;
+      ASSERT_SUCCESS(doc.get_object().get(obj));
+      std::pair<bool,uint64_t> ret = process(obj);
+      ASSERT_TRUE(ret.first);
+      ASSERT_EQUAL(ret.second, 42);
+    }
+
+    {
+      ondemand::parser parser;
+      padded_string json = R"({ "b": { "myint": 42 } })"_padded;
+      std::cout << " - Subtest 'b' - JSON: " << (json) << " ..." << std::endl;
+      ondemand::document doc;
+      ASSERT_SUCCESS(parser.iterate(json).get(doc));
+      ondemand::object obj;
+      ASSERT_SUCCESS(doc.get_object().get(obj));
+      std::pair<bool,uint64_t> ret = process(obj);
+      ASSERT_TRUE(ret.first);
+      ASSERT_EQUAL(ret.second, 42);
+    }
+
+
+    {
+      ondemand::parser parser;
+      padded_string json = R"({ "b": { "myint": 42 }, "a": { "myint": 42 } })"_padded;
+      std::cout << " - Subtest 'b&a' - JSON: " << (json) << " ..." << std::endl;
+      ondemand::document doc;
+      ASSERT_SUCCESS(parser.iterate(json).get(doc));
+      ondemand::object obj;
+      ASSERT_SUCCESS(doc.get_object().get(obj));
+      std::pair<bool,uint64_t> ret = process(obj);
+      ASSERT_FALSE(ret.first);
+      ASSERT_EQUAL(ret.second, 0);
+    }
+
+    {
+      ondemand::parser parser;
+      padded_string json = R"({ "z": { "myint": 42 }, "y": { "myint": 42 } })"_padded;
+      std::cout << " - Subtest 'none' - JSON: " << (json) << " ..." << std::endl;
+      ondemand::document doc;
+      ASSERT_SUCCESS(parser.iterate(json).get(doc));
+      ondemand::object obj;
+      ASSERT_SUCCESS(doc.get_object().get(obj));
+      std::pair<bool,uint64_t> ret = process(obj);
+      ASSERT_FALSE(ret.first);
+      ASSERT_EQUAL(ret.second, 0);
+    }
+
+    TEST_SUCCEED();
+  }
+
   bool run() {
     return
+           issue1876a() &&
+           issue1876() &&
+           test_strager() &&
+           issue1745() &&
            issue1742() &&
            issue1742_value() &&
            issue1723() &&
@@ -997,6 +1234,7 @@ namespace object_tests {
            missing_keys() &&
            missing_keys_for_empty_top_level_object() &&
 #if SIMDJSON_EXCEPTIONS
+           issue1745_with_exceptions() &&
            issue1723_except() &&
            fixed_broken_issue_1521() &&
            issue_1521() &&
